@@ -15,15 +15,7 @@ plot_all <- function(i, gp, gal, shps, dasp, sasp, inner.margins.new, legend_pos
 		proj <- get_projection(shps[[gt$shape.masterID]])
 		
 		if (gt$grid.show) {
-			# non inverse projection avaiable PROJ.4 4.8.0 for Winkel Tripel projection
-			PROJ4_version_nr <- get_proj4_version()
-			
-			if (length(grep("+proj=wintri", proj, fixed = TRUE)) && PROJ4_version_nr < 491 && !is.na(gt$grid.projection)) {
-				warning("Unable to reproject grid lines from the Winkel Triple projection with PROJ.4 version < 4.9.1", call. = FALSE)
-				gt$grid.show <- FALSE
-			} else {
-				gt <- process_grid(gt, bbx, proj, sasp)
-			}
+			gt <- process_grid(gt, bbx, proj, sasp)
 		}
 	}
 
