@@ -11,7 +11,7 @@ plot_map <- function(i, gp, gt, shps, bbx, proj, sasp) {
 	## grid lines
 	## metaX and Y are X and Y margins for the meta plot (legend etc)
 	if (gt$grid.show) {
-		gridRes <- plot_grid(gt, scale=gt$scale, add.labels = gt$grid.labels.inside.frame)
+		gridRes <- plot_grid(gt, scale=gt$scale, add.labels = gt$grid.labels.inside.frame && gt$grid.labels.show)
 		treeGridLines <- gridRes$treeGridLines
 		treeGridLabels <- gridRes$treeGridLabels
 		metaX <- gridRes$metaX
@@ -32,24 +32,13 @@ plot_map <- function(i, gp, gt, shps, bbx, proj, sasp) {
 		
 		## obtain coordinates (to draw bubbles and text)
 		if (inherits(shp, "sf")) {
-			#co.native <- suppressWarnings(st_coordinates(st_geometry(st_centroid(shp)))) #st_coordinates(shp)
 			res <- get_sf_coordinates(shp, gpl)
 			co.native <- res$co
 			if (attr(shp, "point.per")=="segment") {
 				gpl <- res$gpl
 				shp <- res$shp
 			}
-			
-			# co.native <- suppressWarnings(st_coordinates(st_geometry(st_centroid(shp)))) #st_coordinates(shp)
-			
-			# co.npc[,1] <- if (bbx[1, 2]-bbx[1,1]==0) .5 else {
-			# 	(co.npc[,1]-bbx[1,1]) / (bbx[1, 2]-bbx[1,1])	
-			# }
-			# co.npc[,2] <- if (bbx[2, 2]-bbx[2,1]==0) .5 else {
-			# 	(co.npc[,2]-bbx[2,1]) / (bbx[2, 2]-bbx[2,1])
-			# }
 		} else {
-			# co.npc <- NA
 			co.native <- NA
 		}
 
